@@ -1,15 +1,21 @@
 ﻿
 
-__version__ = "0.2020.4.20"
+__version__ = "0.2020.9.21"
 
 
 from .Token import Token
 from .RegExBasedTableTokenizer import RegExBasedTableTokenizer, RegExBasedTokenizingTable
 from .RegExBasedTokenizer import RegExBasedTokenizer
 
+from .TokenizationError import TokenizationError
 
 from .AbstractTokenPattern import AbstractTokenPattern
 from .TokenPattern import TokenPattern
 from .TokenPatternAlternatives import TokenPatternAlternatives
 from .TokenPatternRepeat import TokenPatternRepeat
-from .TokenPatternSequence import TokenPatternSequence
\ No newline at end of file
+from .TokenPatternRepeatUntilNot import TokenPatternRepeatUntilNot
+from .TokenPatternSequence import TokenPatternSequence
+from .TokenPatternDelimLoop import TokenPatternDelimLoop
+
+
+
